import { request } from 'umi';
import { api } from '../api';
import { Paging, SortProps } from '../gameData/rankingList';
let wapi = api + '/gameGsData'


export interface GetBigRProps extends Paging, SortProps {
    roleSource: 1 | 2, // 必填：角色来源：1：区服指派；2：角色指派
    sourceSystem: string, // 必填：SDK来源；默认ZX_ONE
    dtBegin?: string, // 充值统计日期开始
    dtEnd?: string,
    gsIdList?: number[],    // 消耗开始时间
    humanRemoveGameStatus?: 0 | 1, // 人工判断角色退游状态：0：未退游；1：退游
    parentGameId?: number,   // 父游戏id
    roleCreateDayBegin?: string  // 角色创建日期开始
    roleCreateDayEnd?: string
    roleName?: string   // 角色名称
    serveDayBegin?: string, // 服务日期开始
    serveDayEnd?: string,
    serveStatus?: 1 | 2, // 服务状态：1：服务中；2：服务完成
    serverIdList?: string[], // 角色当前所在区服id列表
    superGameId?: number,  //超父游戏id 
    systemRemoveGameStatus?: 0 | 1 // 系统判断角色退游状态：0：未退游；1：退游
}
/**
 * 大R每日充值比
 * @param data 
 * @returns 
 */
export async function getBigRApi(data: GetBigRProps) {
    return request(wapi + `/game/parent/bigR/listOfPage`, {
        method: 'POST',
        data
    });
}

export interface GetRolePayRetainedProps extends Paging, SortProps {
    dtBegin?: string,
    dtEnd?: string,
    gsIdList?: number[],

}
/**
 * 
GS角色付费留存
 * @param data 
 * @returns 
 */
export async function getRolePayRetainedApi(data: GetRolePayRetainedProps) {
    return request(wapi + `/game/parent/role/pay/retained/listOfPage`, {
        method: 'POST',
        data
    });
}

/**
 * 总计
 * @param data 
 * @returns 
 */
export async function getRolePayRetainedTotalApi(data: GetRolePayRetainedProps) {
    return request(wapi + `/game/parent/role/pay/retained/total`, {
        method: 'POST',
        data
    });
}




export interface GetRoleRemoveProps extends Paging, SortProps {
    roleSource: 1 | 2, // 必填：角色来源：1：区服指派；2：角色指派
    sourceSystem: string, // 必填：SDK来源；默认ZX_ONE
    gsIdList?: number[],    // gs id 列表
    parentGameId?: number,   // 父游戏id
    roleCreateDayBegin?: string  // 角色创建日期开始
    roleCreateDayEnd?: string
    roleName?: string   // 角色名称
    serveDayBegin?: string, // 服务日期开始
    serveDayEnd?: string,
    serverIdList?: string[], // 角色当前所在区服id列表
    superGameId?: number,  //超父游戏id
}
/**
 * 大R每日充值比
 * @param data 
 * @returns 
 */
export async function getRoleRemoveListApi(data: GetRoleRemoveProps) {
    return request(wapi + `/game/parent/role/remove/game/monitor`, {
        method: 'POST',
        data
    });
}


export interface GetServerPayRetainedProps extends Paging, SortProps {
    serveDayBegin?: string,  // 服务开始日期
    serveDayEnd?: string,    // 服务结束日期
    gsIdList?: number[],
    gsStatus?: 1 | 2,        // GS运营状态：1：独立运营；2：联合运营
    parentGameId?: number,
    superGameId?: number,
    serveStatus?: 1 | 2,     // 服务状态：1：服务中；2：服务完成
    serverIdList?: number[]  // 角色当前所在区服id列表
    serverStartBegin?: string, // 开服日期
    serverStartEnd?: string, 
}

/**
 * GS角色付费留存
 * @param data 
 * @returns 
 */
export async function getServerPayRetainedApi(data: GetServerPayRetainedProps) {
    return request(wapi + `/game/parent/server/pay/retained/listOfPage`, {
        method: 'POST',
        data
    });
}

/**
 * 总计
 * @param data 
 * @returns 
 */
export async function getServerPayRetainedTotalApi(data: GetServerPayRetainedProps) {
    return request(wapi + `/game/parent/server/pay/retained/total`, {
        method: 'POST',
        data
    });
}

export interface getRoleManageProps extends Paging, SortProps {
    gsIdList?: number[],
    parentGameId?: number,
    superGameId?: number,
    roleCreateDayBegin?: string, // 角色创建日期开始
    roleCreateDayEnd?: string, 
    roleName?: string,
    serveDayBegin?: string,  // 服务开始日期
    serveDayEnd?: string,    // 服务结束日期
    serveStatus?: 1 | 2,     // 服务状态：1：服务中；2：服务完成
    serverIdList?: number[]  // 角色当前所在区服id列表
    gsStatus?: 1 | 2,        // GS运营状态：1：独立运营；2：联合运营
}
/**
 * 游戏角色管理
 * @param data 
 * @returns 
 */
export async function getRoleManageListApi(data: getRoleManageProps) {
    return request(wapi + `/game/parent/role/manage`, {
        method: 'POST',
        data
    });
}


export interface GetServerManageProps extends Paging, SortProps{
    gsIdList?: number[],
    gsStatus?: 1 | 2,        // GS运营状态：1：独立运营；2：联合运营
    parentGameId?: number,
    superGameId?: number,
    serveDayBegin?: string,  // 服务开始日期
    serveDayEnd?: string,    // 服务结束日期
    serveStatus?: 1 | 2,     // 服务状态：1：服务中；2：服务完成
    serverIdList?: number[]  // 角色当前所在区服id列表
    serverStartBegin?: string, // 开服日期
    serverStartEnd?: string, 
}
/**
 * 游戏区服管理
 * @param data 
 * @returns 
 */
export async function getServerManageListApi(data: GetServerManageProps) {
    return request(wapi + `/game/parent/serve/manage`, {
        method: 'POST',
        data
    });
}


export interface GetRoleLevelListProps extends Paging, SortProps{
    roleName?: string
    roleId?: string
    gameName?: string
    gameId?: string
    serverName?: string
    serverId?: string
    createTimeMin?: string
    createTimeMax?: string
    roleLevelMin?: number
    roleLevelMax?: number
    levelTimeMin?: number
    levelTimeMax?: number
}
/**
 * 角色等级列表 仙剑
 * @param data 
 * @returns 
 */
export async function getRoleLevelListApi(data: GetRoleLevelListProps) {
    return request(api + `/gameData/role/level/listOfPage`, {
        method: 'POST',
        data
    });
}